@@ -71,7 +71,10 @@ def test_core_config_load_dump(path, serializer, tmpdir):
     else:
         # Dump config to file
         with Path(path).open("w") as file:
-            serializer.dump(config, file)
+            if serializer is json:
+                serializer.dump(config, file, indent=4)
+            else:
+                serializer.dump(config, file)
 
         # Read content of the dump
         with Path(path).open() as file:
@@ -87,6 +90,59 @@ def test_core_config_load_dump(path, serializer, tmpdir):
             assert file.read() == content
 
 
+@pytest.mark.parametrize(
+    "files, expected",
+    [
+        pytest.param(
+            {"config.yaml": "foo: 1\nbar: !include bar.yaml", "bar.yaml": "2"}, {"foo": 1, "bar": 2}, id="simple"
+        ),
+        pytest.param(
+            {"config.yaml": "foo: 1\n<<: !include bar.yaml", "bar.yaml": "bar: 2"},
+            {"foo": 1, "bar": 2},
+            id="simple-merge",
+        ),
+        pytest.param(
+            {"config.yaml": "foo: 1\n<<: !include bar.yaml", "bar.yaml": "2"}, None, id="simple-merge-invalid"
+        ),
+        pytest.param(
+            {"config.yaml": "foo: 1\nbar: !include bar/bar.yaml", "bar/bar.yaml": "2"},
+            {"foo": 1, "bar": 2},
+            id="nested",
+        ),
+        pytest.param(
+            {"config.yaml": "foo: 1\n<<: !include bar/bar.yaml", "bar/bar.yaml": "bar: 2"},
+            {"foo": 1, "bar": 2},
+            id="nested-merge",
+        ),
+        pytest.param(
+            {
+                "config.yaml": "foo: 1\nbar: !include bar/bar.yaml",
+                "bar/bar.yaml": "!include baz.yaml",
+                "bar/baz.yaml": "2",
+            },
+            {"foo": 1, "bar": 2},
+            id="nested-twice",
+        ),
+        pytest.param(
+            {
+                "config.yaml": "foo: 1\n<<: !include bar/bar.yaml",
+                "bar/bar.yaml": "<<: !include baz.yaml",
+                "bar/baz.yaml": "bar: 2",
+            },
+            {"foo": 1, "bar": 2},
+            id="nested-twice-merge",
+        ),
+    ],
+)
+def test_core_config_load_include_merge(files, expected, tmpdir):
+    """Test include and merge functionality."""
+    for p, content in files.items():
+        Path(tmpdir, p).parent.mkdir(parents=True, exist_ok=True)
+        with Path(tmpdir, p).open("w") as file:
+            file.write(content)
+    assert fromconfig.load(Path(tmpdir, "config.yaml")) == expected
+
+
 @pytest.mark.parametrize(
     "config, expected",
     [
